@@ -9,9 +9,13 @@ from .unpack import (unpack_to_array,
                      unpack_to_dict,
                      )
 
+# Make this available to catch exceptions
+from .tools.validation import InvalidProductSpec
+
 __all__ = ['list_sensors',
            'list_products',
            'list_qa_flags',
            'unpack_to_array',
            'unpack_to_dict',
+           'InvalidProductSpec',
            ]
\ No newline at end of file
